=== modified file 'drizzled/parser.cc'
--- drizzled/parser.cc	2011-10-19 17:58:50 +0000
+++ drizzled/parser.cc	2011-10-22 13:10:53 +0000
@@ -67,8 +67,6 @@
     expression the <subquery> is.
   */
 
-  Item *result;
-
   if (expr->type() == Item::SUBSELECT_ITEM)
   {
     Item_subselect *expr2 = (Item_subselect*) expr;
@@ -76,7 +74,6 @@
     if (expr2->substype() == Item_subselect::SINGLEROW_SUBS)
     {
       Item_singlerow_subselect *expr3 = (Item_singlerow_subselect*) expr2;
-      Select_Lex *subselect;
 
       /*
         Implement the mandated change, by altering the semantic tree:
@@ -86,22 +83,14 @@
         which is represented as
           Item_in_subselect(left, subselect)
       */
-      subselect= expr3->invalidate_and_restore_select_lex();
-      result= new (session->mem_root) Item_in_subselect(left, subselect);
-
-      if (! equal)
-        result = negate_expression(session, result);
-
-      return(result);
+      Select_Lex* subselect= expr3->invalidate_and_restore_select_lex();
+      Item* result= new (session->mem_root) Item_in_subselect(left, subselect);
+      return equal ? result : negate_expression(session, result);
     }
   }
-
-  if (equal)
-    result= new (session->mem_root) Item_func_eq(left, expr);
-  else
-    result= new (session->mem_root) Item_func_ne(left, expr);
-
-  return(result);
+  return equal
+    ? (Item*) new (session->mem_root) Item_func_eq(left, expr)
+    : (Item*) new (session->mem_root) Item_func_ne(left, expr);
 }
 
 /**

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2011-10-18 11:48:44 +0000
+++ drizzled/session.cc	2011-10-22 13:10:53 +0000
@@ -102,9 +102,9 @@
 
 bool Key_part_spec::operator==(const Key_part_spec& other) const
 {
-  return length == other.length &&
-         field_name.size() == other.field_name.size() &&
-    !my_strcasecmp(system_charset_info, field_name.data(), other.field_name.data());
+  return length == other.length 
+    && field_name.size() == other.field_name.size()
+    && not my_strcasecmp(system_charset_info, field_name.data(), other.field_name.data());
 }
 
 Open_tables_state::Open_tables_state(Session& session, uint64_t version_arg) :

=== modified file 'drizzled/sql_parse.cc'
--- drizzled/sql_parse.cc	2011-10-19 09:25:53 +0000
+++ drizzled/sql_parse.cc	2011-10-22 13:10:53 +0000
@@ -901,8 +901,7 @@
   if (!table)
     return NULL;				// End of memory
   const char* alias_str= alias ? alias->data() : table->table.data();
-  if (not table_options.test(TL_OPTION_ALIAS) &&
-      check_table_name(table->table.data(), table->table.size()))
+  if (not table_options.test(TL_OPTION_ALIAS) && check_table_name(table->table))
   {
     my_error(ER_WRONG_TABLE_NAME, MYF(0), table->table.data());
     return NULL;

=== modified file 'drizzled/sql_yacc.yy'
--- drizzled/sql_yacc.yy	2011-10-19 17:58:50 +0000
+++ drizzled/sql_yacc.yy	2011-10-22 13:10:53 +0000
@@ -2014,7 +2014,7 @@
               Lex.select_lex.db = db.data();
             }
 
-            if (check_table_name($3->table.data(), $3->table.size()))
+            if (check_table_name($3->table))
             {
               my_error(ER_WRONG_TABLE_NAME, MYF(0), $3->table.data());
               DRIZZLE_YYABORT;

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2011-10-16 17:36:34 +0000
+++ drizzled/table.cc	2011-10-22 13:10:53 +0000
@@ -306,13 +306,9 @@
   ' ' at the end
   returns 1 on error
 */
-bool check_table_name(const char *name, uint32_t length)
+bool check_table_name(str_ref str)
 {
-  if (!length || length > NAME_LEN || name[length - 1] == ' ')
-    return 1;
-  lex_string_t ident;
-  ident.assign(name, length);
-  return check_identifier_name(ident);
+  return str.empty() || str.size() > NAME_LEN || str.data()[str.size() - 1] == ' ' || check_identifier_name(str);
 }
 
 

=== modified file 'drizzled/table.h'
--- drizzled/table.h	2011-08-12 16:41:20 +0000
+++ drizzled/table.h	2011-10-22 13:10:53 +0000
@@ -796,8 +796,8 @@
 ulong get_form_pos(int file, unsigned char *head, TYPELIB *save_names);
 void append_unescaped(String *res, const char *pos, uint32_t length);
 
-bool check_column_name(const char *name);
-bool check_table_name(const char *name, uint32_t length);
+bool check_column_name(const char*);
+bool check_table_name(str_ref);
 
 } /* namespace drizzled */
 

=== modified file 'drizzled/util/data_ref.h'
--- drizzled/util/data_ref.h	2011-10-19 17:58:50 +0000
+++ drizzled/util/data_ref.h	2011-10-22 13:10:53 +0000
@@ -96,6 +96,11 @@
   {
     return begin() == end();
   }
+
+  operator std::string() const
+  {
+    return to_string(*this);
+  }
 private:
   T begin_;
   T end_;

